[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/emcek/no_sleep/master.svg)](https://results.pre-commit.ci/latest/github/emcek/no_sleep/master)
[![License](https://img.shields.io/badge/License-MIT-blue.svg)](./LICENSE)
[![image](https://img.shields.io/badge/python-3.9%20%7C%203.10%20%7C%203.11%20%7C%203.12%20%7C%203.13-blue.svg)](https://github.com/emcek/no_sleep)

# no_sleep
No more sleep.

## installation
The preferred way of installing using [uv](https://github.com/astral-sh/uv) (v0.5.11 or newer) tool:
``` console
uv tool install --python 3.13.1 no_sleep
```
Please use Python 3.13.1+ (or any 3.12.x) due to 3.13.0 run extra terminal window even if it was disabled.

## update
``` console
uv tool update no_sleep
```

## uninstall
``` console
uv tool uninstall no_sleep
```
